================================
``psyclone.tests.psyir.backend``
================================

.. automodule:: psyclone.tests.psyir.backend

   .. contents::
      :local:


Submodules
==========

.. toctree::

   psyclone.tests.psyir.backend.c_test
   psyclone.tests.psyir.backend.fortran_format_stmt_test
   psyclone.tests.psyir.backend.fortran_gen_decls_test
   psyclone.tests.psyir.backend.fortran_test
   psyclone.tests.psyir.backend.fortran_unknown_declns_test
   psyclone.tests.psyir.backend.language_writer_test
   psyclone.tests.psyir.backend.opencl_test
   psyclone.tests.psyir.backend.psyir_openacc_test
   psyclone.tests.psyir.backend.psyir_openmp_test
   psyclone.tests.psyir.backend.sir_test
   psyclone.tests.psyir.backend.sympy_writer_test
   psyclone.tests.psyir.backend.visitor_test

.. currentmodule:: psyclone.tests.psyir.backend
